@@ -92,6 +92,7 @@ func main() {
 			if *user != "" {
 				args = append(args, []string{"--user", *user}...)
 			}
+
 			cmd := &exec.Cmd{
 				Path:   "/usr/bin/debconf",
 				Args:   args,
@@ -146,12 +147,16 @@ func main() {
 		log.Fatalf("Invalid --tags value(s): %s", err)
 	}
 
-	pkgs = dropAmbiguousPkgs(pkgs)
-
+	// Augment pkgs with provider packages (unclear whether this actually
+	// makes a difference), and eliminate duplicates and ambiguous package
+	// names (see uniqArchFreePkgs() on what the latter means) before dpkg
+	// invocations.
+	pkgs = uniqArchFreePkgs(pkgs)
 	pkgProvides := packageProvides(ignoreMissingPackages, pkgs)
 	for p := range pkgProvides {
 		pkgs = append(pkgs, p)
 	}
+	pkgs = uniqArchFreePkgs(pkgs)
 
 	pkgFiles, totalFiles, err := packageFiles(pkgs)
 	if err != nil {
@@ -204,7 +209,6 @@ func main() {
 			os.Exit(2)
 		}
 	}
-
 }
 
 func mapTags[T error](errs []T) []string {
@@ -281,7 +285,9 @@ func checkArgs(args []string) error {
 	return nil
 }
 
-func dropAmbiguousPkgs(pkgs []string) []string {
+// uniqArchFreePkgs eliminates from the passed package slice, any duplicates and
+// any arch-free packages for which an arch-specific one exists.
+func uniqArchFreePkgs(pkgs []string) []string {
 	existsWithArch := make(map[string]bool)
 	for _, p := range pkgs {
 		if i := strings.Index(p, ":"); i != -1 {
@@ -290,9 +296,11 @@ func dropAmbiguousPkgs(pkgs []string) []string {
 	}
 
 	var newPkgs []string
+	seen := make(map[string]bool)
 	for _, p := range pkgs {
-		if !existsWithArch[p] {
+		if !existsWithArch[p] && !seen[p] {
 			newPkgs = append(newPkgs, p)
+			seen[p] = true
 		}
 	}
 
